@@ -1,44 +1,38 @@
-#include <qpdf/qpdf-config.h>  // include first for large file support
+#include <qpdf/qpdf-config.h> // include first for large file support
 
 #include <qpdf/Pl_StdioFile.hh>
 
 #include <qpdf/QUtil.hh>
-#include <stdexcept>
 #include <errno.h>
+#include <stdexcept>
 
 Pl_StdioFile::Members::Members(FILE* f) :
     file(f)
 {
 }
 
-Pl_StdioFile::Members::~Members()
-{
-}
-
 Pl_StdioFile::Pl_StdioFile(char const* identifier, FILE* f) :
-    Pipeline(identifier, 0),
+    Pipeline(identifier, nullptr),
     m(new Members(f))
 {
 }
 
 Pl_StdioFile::~Pl_StdioFile()
 {
+    // Must be explicit and not inline -- see QPDF_DLL_CLASS in
+    // README-maintainer
 }
 
 void
-Pl_StdioFile::write(unsigned char* buf, size_t len)
+Pl_StdioFile::write(unsigned char const* buf, size_t len)
 {
     size_t so_far = 0;
-    while (len > 0)
-    {
+    while (len > 0) {
         so_far = fwrite(buf, 1, len, this->m->file);
-        if (so_far == 0)
-        {
+        if (so_far == 0) {
             QUtil::throw_system_error(
                 this->identifier + ": Pl_StdioFile::write");
-        }
-        else
-        {
+        } else {
             buf += so_far;
             len -= so_far;
         }
@@ -48,11 +42,8 @@ Pl_StdioFile::write(unsigned char* buf, size_t len)
 void
 Pl_StdioFile::finish()
 {
-    if ((fflush(this->m->file) == -1) &&
-        (errno == EBADF))
-    {
+    if ((fflush(this->m->file) == -1) && (errno == EBADF)) {
         throw std::logic_error(
-            this->identifier +
-            ": Pl_StdioFile::finish: stream already closed");
+            this->identifier + ": Pl_StdioFile::finish: stream already closed");
     }
 }
